from setuptools import setup

setup(
	name="diffpatch",
	version="1.0.0",
	author="Isaac Turner",
	url="https://gist.github.com/noporpoise/16e731849eb1231e86d78f9dfeca3abc",
	description="A library to make and apply patches"
)